==> haskell-hasql-transaction-1.0.1.1-391-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-Fjn1XHAV7bD6IChYFi2fVs
key:                  hasql-transaction-1.0.1.1-Fjn1XHAV7bD6IChYFi2fVs
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  3cd6daf6a8378074660ae8cd7bf1a094
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-Fjn1XHAV7bD6IChYFi2fVs
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-9exHcHyT3Hi8l5N32wZ7p8
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-G0Qum68lPyK2IfU9Q4xYR0 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-392-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-84ZZdZ3SYHT4vYUhVlFJvG
key:                  hasql-transaction-1.0.1.1-84ZZdZ3SYHT4vYUhVlFJvG
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  d48f0d6fe5a1064713aac9c2652d1a83
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-84ZZdZ3SYHT4vYUhVlFJvG
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-9exHcHyT3Hi8l5N32wZ7p8
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-Cggvq4f3fZJB7w4rdXL4OF mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
